import 'isomorphic-fetch';
import { BaseCommand } from '../../types';
import { BatchableCommand } from './httpClient';
/**
 * Sends an http request to a specified host.
 *
 * @method send
 *
 * @memberof module:http-client
 *
 * @param {Command} command
 *
 * @param {String} [uri=http://localhost:14265]
 *
 * @param {String|Number} [apiVersion=1]
 *
 * @return Promise
 * @fulil {Object} - Response
 * @reject {Error} - Request error
 */
export declare const send: <C extends BaseCommand, R = any>(command: C, uri?: string, apiVersion?: string | number) => Promise<R>;
/**
 * Sends a batched http request to a specified host
 * supports findTransactions, getBalances & getTrytes commands
 *
 * @method batchedSend
 *
 * @param {Command} command
 *
 * @param {String[]} keysToBatch
 *
 * @param {Number} [requestBatchSize=1000]
 *
 * @param {String} [uri='http://localhost:14265']
 *
 * @param {String|Number} [apiVersion=1]
 *
 * @ignore
 *
 * @return Promise
 * @fulil {Object} - Response
 * @reject {Error} - Request error
 */
export declare const batchedSend: <C extends BaseCommand, R = any>(command: BatchableCommand<C>, keysToBatch: ReadonlyArray<string>, requestBatchSize?: number, uri?: string, apiVersion?: string | number) => Promise<any>;
